@@ -31,13 +31,13 @@ def _cmd_apply_blacklist(): #{{{1
         dicts.write()
 
 def _cmd_run_gui(): #{{{1
-    from PyQt4.QtGui  import QApplication, QMessageBox
-    from ACE_gui      import ACEMainWindow
+    from PyQt4.QtGui import QApplication
     import traceback
 
     app = QApplication(sys.argv)
 
     try:
+        from ACE_gui import ACEMainWindow
         w = ACEMainWindow()
         w.show()
         w.setupMenu()
@@ -46,6 +46,7 @@ def _cmd_run_gui(): #{{{1
 
         app.exec_()
     except Exception, e:
+        from PyQt4.QtGui import QMessageBox
         QMessageBox.critical(None, 'Error', traceback.format_exc(2))
 
 if __name__ == '__main__': #{{{1
